@@ -3,10 +3,10 @@ def test_repair_non_numeric():
     Test repair_non_numeric method
     """
     import numpy as np
-    from spotPython.fun.objectivefunctions import analytical
-    from spotPython.spot.spot import Spot
-    from spotPython.utils.repair import repair_non_numeric
-    from spotPython.utils.init import (
+    from spotpython.fun.objectivefunctions import analytical
+    from spotpython.spot.spot import Spot
+    from spotpython.utils.repair import repair_non_numeric
+    from spotpython.utils.init import (
         fun_control_init,
         design_control_init,
     )
